@@ -26,9 +26,10 @@ if tp.TYPE_CHECKING:
     from static_frame.core.series import Series # pylint: disable=W0611 #pragma: no cover
     from static_frame.core.index import Index # pylint: disable=W0611 #pragma: no cover
     from static_frame.core.quilt import Quilt # pylint: disable=W0611 #pragma: no cover
+    from static_frame.core.bus import Bus # pylint: disable=W0611 #pragma: no cover
 
 
-FrameOrSeries = tp.TypeVar('FrameOrSeries', 'Frame', 'Series', 'Quilt')
+FrameOrSeries = tp.TypeVar('FrameOrSeries', 'Frame', 'Series', 'Bus', 'Quilt')
 # FrameSeriesIndex = tp.TypeVar('FrameSeriesIndex', 'Frame', 'Series', 'Index')
 
 
@@ -350,10 +351,12 @@ class IterNodeDelegate(tp.Generic[FrameOrSeries]):
 
         Args:
             {func}
+            *
             {dtype}
-            max_workers: Passed to the pool_executor, where None defaults to the max number of machine processes.
-            chunksize: Passed to the pool executor.
-            use_thread: When True, the ThreadPoolExecutor will be used rather than the default ProcessPoolExecutor.
+            {name}
+            {max_workers}
+            {chunksize}
+            {use_threads}
         '''
         return self._apply_constructor(
                 self._apply_iter_items_parallel(
@@ -447,9 +450,9 @@ class IterNode(tp.Generic[FrameOrSeries]):
 
         elif self._apply_type is IterNodeApplyType.FRAME_ELEMENTS:
             assert isinstance(self._container, Frame) # for typing
-            # for element-wise function application, axis will always be 0 or 1, as we always do full iteration; from_element_loc_items accepts axis of None for incomplete specification, but that will never be used here.
+            # for element-wise function application, axis will always be 0 or 1, as we always do full iteration; from_element_items accepts axis of None for incomplete specification, but that will never be used here.
             apply_constructor = partial(
-                    self._container.__class__.from_element_loc_items,
+                    self._container.__class__.from_element_items,
                     index=self._container._index,
                     columns=self._container._columns,
                     axis=kwargs['axis'],
