@@ -6,7 +6,7 @@ import numpy as np
 from static_frame.core.interface import InterfaceSummary
 from static_frame.core.series import Series
 from static_frame.core.frame import FrameGO
-
+from static_frame.core.frame import Frame
 from static_frame.core.interface import _get_signatures
 
 
@@ -31,7 +31,7 @@ class TestUnit(TestCase):
 
         self.assertEqual(
             counts.to_pairs(),
-            (('Accessor Datetime', 10), ('Accessor String', 36), ('Accessor Transpose', 23), ('Assignment', 4), ('Attribute', 11), ('Constructor', 31), ('Dictionary-Like', 7), ('Display', 6), ('Exporter', 21), ('Iterator', 224), ('Method', 67), ('Operator Binary', 24), ('Operator Unary', 4), ('Selector', 13))
+            (('Accessor Datetime', 10), ('Accessor String', 36), ('Accessor Transpose', 23), ('Assignment', 8), ('Attribute', 11), ('Constructor', 30), ('Dictionary-Like', 7), ('Display', 6), ('Exporter', 21), ('Iterator', 224), ('Method', 67), ('Operator Binary', 24), ('Operator Unary', 4), ('Selector', 13))
         )
 
     def test_interface_summary_c(self) -> None:
@@ -72,6 +72,14 @@ class TestUnit(TestCase):
                 ['cls_name', 'group', 'doc', 'reference', 'use_signature', 'is_attr', 'delegate_reference', 'delegate_is_attr', 'signature_no_args']
                 )
 
+    def test_interface_assign_a(self) -> None:
+        f = Frame.interface.loc[Frame.interface.index.via_str.startswith('assign')]
+        # assignmewnt interface is one of the most complex, so we can check the signatures here explicitly
+        self.assertEqual(f.index.values.tolist(),
+                ['assign[key](value, *, fill_value)', 'assign[key].apply(func, *, fill_value)', 'assign.iloc[key](value, *, fill_value)', 'assign.iloc[key].apply(func, *, fill_value)', 'assign.loc[key](value, *, fill_value)', 'assign.loc[key].apply(func, *, fill_value)', 'assign.bloc[key](value, *, fill_value)', 'assign.bloc[key].apply(func, *, fill_value)'])
+
+
+
 
 if __name__ == '__main__':
     unittest.main()
