@@ -61,6 +61,8 @@ from static_frame.core.util import union1d
 from static_frame.core.util import union2d
 from static_frame.core.util import duplicate_filter
 from static_frame.core.util import array_deepcopy
+from static_frame.core.util import array_from_element_apply
+from static_frame.core.util import get_tuple_constructor
 
 from static_frame.test.test_case import TestCase
 from static_frame.test.test_case import UnHashable
@@ -1793,6 +1795,10 @@ class TestUnit(TestCase):
         self.assertTrue(a1[1] == FxISO.CDF)
         # NOTE: in check does not work here
 
+    def test_iterable_to_array_k(self) -> None:
+        with self.assertRaises(RuntimeError):
+            _, _ = iterable_to_array_1d(np.array([[3,],[4,]]))
+
     #---------------------------------------------------------------------------
 
     def test_iterable_to_array_2d_a(self) -> None:
@@ -1822,6 +1828,10 @@ class TestUnit(TestCase):
             # looks like a 2d array enough to get past type sampling
             post = iterable_to_array_2d(['asd', 'wer'])
 
+    def test_iterable_to_array_2d_d(self) -> None:
+        with self.assertRaises(RuntimeError):
+            post = iterable_to_array_2d(np.array(['asd', 'wer']))
+
 
     #---------------------------------------------------------------------------
 
@@ -2319,6 +2329,14 @@ class TestUnit(TestCase):
         a9 = np.array([False])
         self.assertEqual(array1d_to_last_contiguous_to_edge(a9), 1)
 
+    def test_array1d_to_last_contiguous_to_edge_b(self) -> None:
+
+        a1 = np.array([False, False, False, False])
+        self.assertEqual(array1d_to_last_contiguous_to_edge(a1), 4)
+
+        a2 = np.array([False, False, True, True, False, True, True])
+        self.assertEqual(array1d_to_last_contiguous_to_edge(a2), 5)
+
     #---------------------------------------------------------------------------
     def test_array_sample_a(self) -> None:
         a1 = np.arange(10)
@@ -2332,11 +2350,16 @@ class TestUnit(TestCase):
         self.assertEqual(array_sample(a1, 4, seed=1).tolist(), [3, 2, 0, 1])
         self.assertEqual(array_sample(a1, 4, seed=1, sort=True).tolist(), [0, 1, 2, 3])
 
+    def test_array_sample_c(self) -> None:
+        a1 = np.arange(4)
 
         with self.assertRaises(ValueError):
             # raises if count is greater than size of array
             self.assertEqual(array_sample(a1, 6, seed=1).tolist(), [3, 2, 0, 1])
 
+        with self.assertRaises(NotImplementedError):
+            _ = array_sample(a1.reshape(2, 2), 2)
+
 
     #---------------------------------------------------------------------------
     def test_duplicate_filter_a(self) -> None:
@@ -2377,6 +2400,20 @@ class TestUnit(TestCase):
         self.assertFalse(a2.flags.writeable)
         self.assertEqual(a2.tolist()[:3], [3, None, 20])
 
+    #---------------------------------------------------------------------------
+    def test_array_from_element_apply_a(self) -> None:
+        a1 = np.array([1, 2, 3])
+        post = array_from_element_apply(array=a1, func=lambda e: e + 1, dtype=a1.dtype)
+        self.assertEqual(post.tolist(), [2, 3, 4])
+
+    #---------------------------------------------------------------------------
+    def test_get_tuple_constructor_a(self) -> None:
+        cls1 = get_tuple_constructor(('a', 'b'))
+        self.assertTrue(callable(cls1))
+
+        with self.assertRaises(ValueError):
+            cls2 = get_tuple_constructor(('a ', '3*'))
+
 
 if __name__ == '__main__':
     unittest.main()
